"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCompilerInstance = exports.updateOutput = exports.SOURCE_MAPPING_PREFIX = void 0;
const language_service_1 = require("./language-service");
const transpiler_1 = require("./transpiler");
const json_1 = require("../utils/json");
exports.SOURCE_MAPPING_PREFIX = 'sourceMappingURL=';
function updateOutput(outputText, normalizedFileName, sourceMap) {
    const base64Map = Buffer.from(updateSourceMap(sourceMap, normalizedFileName), 'utf8').toString('base64');
    const sourceMapContent = `data:application/json;charset=utf-8;base64,${base64Map}`;
    return (outputText.slice(0, outputText.lastIndexOf(exports.SOURCE_MAPPING_PREFIX) + exports.SOURCE_MAPPING_PREFIX.length) + sourceMapContent);
}
exports.updateOutput = updateOutput;
const updateSourceMap = (sourceMapText, normalizedFileName) => {
    const sourceMap = JSON.parse(sourceMapText);
    sourceMap.file = normalizedFileName;
    sourceMap.sources = [normalizedFileName];
    delete sourceMap.sourceRoot;
    return json_1.stringify(sourceMap);
};
const compileAndUpdateOutput = (compileFn, logger) => (code, fileName, lineOffset) => {
    logger.debug({ fileName }, 'compileAndUpdateOutput(): get compile output');
    const [value, sourceMap] = compileFn(code, fileName, lineOffset);
    return updateOutput(value, fileName, sourceMap);
};
exports.createCompilerInstance = (configs) => {
    const logger = configs.logger.child({ namespace: 'ts-compiler' });
    const { parsedTsConfig: { options: compilerOptions }, } = configs;
    const extensions = ['.ts', '.tsx'];
    if (compilerOptions.allowJs) {
        extensions.push('.js');
        extensions.push('.jsx');
    }
    const compilerInstance = !configs.isolatedModules
        ? language_service_1.initializeLanguageServiceInstance(configs, logger)
        : transpiler_1.initializeTranspilerInstance(configs, logger);
    const compile = compileAndUpdateOutput(compilerInstance.compileFn, logger);
    return { cwd: configs.cwd, compile, program: compilerInstance.program };
};
