"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeTranspilerInstance = void 0;
exports.initializeTranspilerInstance = (configs, logger) => {
    logger.debug('initializeTranspilerInstance(): create typescript compiler');
    const { options } = configs.parsedTsConfig;
    const ts = configs.compilerModule;
    return {
        compileFn: (code, fileName) => {
            logger.debug({ fileName }, 'compileFn(): compiling as isolated module');
            const result = ts.transpileModule(code, {
                fileName,
                transformers: configs.customTransformers,
                compilerOptions: options,
                reportDiagnostics: configs.shouldReportDiagnostics(fileName),
            });
            if (result.diagnostics && configs.shouldReportDiagnostics(fileName)) {
                configs.raiseDiagnostics(result.diagnostics, fileName, logger);
            }
            return [result.outputText, result.sourceMapText];
        },
        program: undefined,
    };
};
